package java.awt;

public final class Color {
   public static final Color white = new Color(255, 255, 255);
   public static final Color lightGray = new Color(192, 192, 192);
   public static final Color gray = new Color(128, 128, 128);
   public static final Color darkGray = new Color(64, 64, 64);
   public static final Color black = new Color(0, 0, 0);
   public static final Color red = new Color(255, 0, 0);
   public static final Color pink = new Color(255, 175, 175);
   public static final Color orange = new Color(255, 200, 0);
   public static final Color yellow = new Color(255, 255, 0);
   public static final Color green = new Color(0, 255, 0);
   public static final Color magenta = new Color(255, 0, 255);
   public static final Color cyan = new Color(0, 255, 255);
   public static final Color blue = new Color(0, 0, 255);
   private int pData;
   private int value;
   private static final double FACTOR = 0.7;

   public Color(int r, int g, int b) {
      this((r & 255) << 16 | (g & 255) << 8 | b & 255);
   }

   public Color(int rgb) {
      this.value = -16777216 | rgb;
   }

   public Color(float r, float g, float b) {
      this((int)(r * 255.0F), (int)(g * 255.0F), (int)(b * 255.0F));
   }

   public int getRed() {
      return this.value >> 16 & 255;
   }

   public int getGreen() {
      return this.value >> 8 & 255;
   }

   public int getBlue() {
      return this.value & 255;
   }

   public int getRGB() {
      return this.value;
   }

   public Color brighter() {
      return new Color(Math.min((int)((double)this.getRed() * 1.4285714285714286), 255), Math.min((int)((double)this.getGreen() * 1.4285714285714286), 255), Math.min((int)((double)this.getBlue() * 1.4285714285714286), 255));
   }

   public Color darker() {
      return new Color(Math.max((int)((double)this.getRed() * 0.7), 0), Math.max((int)((double)this.getGreen() * 0.7), 0), Math.max((int)((double)this.getBlue() * 0.7), 0));
   }

   public int hashCode() {
      return this.value;
   }

   public boolean equals(Object obj) {
      if (obj instanceof Color) {
         return this.value == ((Color)obj).value;
      } else {
         return false;
      }
   }

   public String toString() {
      return this.getClass().getName() + "[r=" + this.getRed() + ",g=" + this.getGreen() + ",b=" + this.getBlue() + "]";
   }

   public static Color getColor(String nm) {
      return getColor(nm, (Color)null);
   }

   public static Color getColor(String nm, Color v) {
      Integer intval = Integer.getInteger(nm);
      if (intval == null) {
         return v;
      } else {
         int i = intval;
         return new Color(i >> 16 & 255, i >> 8 & 255, i & 255);
      }
   }

   public static Color getColor(String nm, int v) {
      Integer intval = Integer.getInteger(nm);
      int i = intval != null ? intval : v;
      return new Color(i >> 16 & 255, i >> 8 & 255, i & 255);
   }

   public static int HSBtoRGB(float hue, float saturation, float brightness) {
      int r = 0;
      int g = 0;
      int b = 0;
      if (saturation == 0.0F) {
         r = g = b = (int)(brightness * 255.0F);
      } else {
         double h = (double)hue * (double)6.0F;
         double f = h - Math.floor(h);
         double p = (double)brightness * ((double)1.0F - (double)saturation);
         double q = (double)brightness * ((double)1.0F - (double)saturation * f);
         double t = (double)brightness * ((double)1.0F - (double)saturation * ((double)1.0F - f));
         switch ((int)h) {
            case 0:
               r = (int)(brightness * 255.0F);
               g = (int)(t * (double)255.0F);
               b = (int)(p * (double)255.0F);
               break;
            case 1:
               r = (int)(q * (double)255.0F);
               g = (int)(brightness * 255.0F);
               b = (int)(p * (double)255.0F);
               break;
            case 2:
               r = (int)(p * (double)255.0F);
               g = (int)(brightness * 255.0F);
               b = (int)(t * (double)255.0F);
               break;
            case 3:
               r = (int)(p * (double)255.0F);
               g = (int)(q * (double)255.0F);
               b = (int)(brightness * 255.0F);
               break;
            case 4:
               r = (int)(t * (double)255.0F);
               g = (int)(p * (double)255.0F);
               b = (int)(brightness * 255.0F);
               break;
            case 5:
               r = (int)(brightness * 255.0F);
               g = (int)(p * (double)255.0F);
               b = (int)(q * (double)255.0F);
         }
      }

      return -16777216 | r << 16 | g << 8 | b;
   }

   public static float[] RGBtoHSB(int r, int g, int b, float[] hsbvals) {
      if (hsbvals == null) {
         hsbvals = new float[3];
      }

      int cmax = r > g ? r : g;
      if (b > cmax) {
         cmax = b;
      }

      int cmin = r < g ? r : g;
      if (b < cmin) {
         cmin = b;
      }

      float brightness = (float)cmax / 255.0F;
      float saturation;
      if (cmax != 0) {
         saturation = (float)(cmax - cmin) / (float)cmax;
      } else {
         saturation = 0.0F;
      }

      float hue;
      if (saturation == 0.0F) {
         hue = 0.0F;
      } else {
         float redc = (float)(cmax - r) / (float)(cmax - cmin);
         float greenc = (float)(cmax - g) / (float)(cmax - cmin);
         float bluec = (float)(cmax - b) / (float)(cmax - cmin);
         if (r == cmax) {
            hue = bluec - greenc;
         } else if (g == cmax) {
            hue = 2.0F + redc - bluec;
         } else {
            hue = 4.0F + greenc - redc;
         }

         hue /= 6.0F;
         if (hue < 0.0F) {
            ++hue;
         }
      }

      hsbvals[0] = hue;
      hsbvals[1] = saturation;
      hsbvals[2] = brightness;
      return hsbvals;
   }

   public static Color getHSBColor(float h, float s, float b) {
      return new Color(HSBtoRGB(h, s, b));
   }
}
