package java.awt;

import java.awt.image.ImageObserver;

public abstract class Graphics {
   protected Graphics() {
   }

   public abstract Graphics create();

   public Graphics create(int x, int y, int width, int height) {
      Graphics g = this.create();
      g.translate(x, y);
      g.clipRect(0, 0, width, height);
      return g;
   }

   public abstract void translate(int var1, int var2);

   public abstract Color getColor();

   public abstract void setColor(Color var1);

   public abstract void setPaintMode();

   public abstract void setXORMode(Color var1);

   public abstract Font getFont();

   public abstract void setFont(Font var1);

   public FontMetrics getFontMetrics() {
      return this.getFontMetrics(this.getFont());
   }

   public abstract FontMetrics getFontMetrics(Font var1);

   public abstract Rectangle getClipRect();

   public abstract void clipRect(int var1, int var2, int var3, int var4);

   public abstract void copyArea(int var1, int var2, int var3, int var4, int var5, int var6);

   public abstract void drawLine(int var1, int var2, int var3, int var4);

   public abstract void fillRect(int var1, int var2, int var3, int var4);

   public void drawRect(int x, int y, int width, int height) {
      this.drawLine(x, y, x + width, y);
      this.drawLine(x + width, y, x + width, y + height);
      this.drawLine(x, y, x, y + height);
      this.drawLine(x, y + height, x + width, y + height);
   }

   public abstract void clearRect(int var1, int var2, int var3, int var4);

   public abstract void drawRoundRect(int var1, int var2, int var3, int var4, int var5, int var6);

   public abstract void fillRoundRect(int var1, int var2, int var3, int var4, int var5, int var6);

   public void draw3DRect(int x, int y, int width, int height, boolean raised) {
      Color c = this.getColor();
      Color brighter = c.brighter();
      Color darker = c.darker();
      this.setColor(raised ? brighter : darker);
      this.drawLine(x, y, x, y + height);
      this.drawLine(x + 1, y, x + width - 1, y);
      this.setColor(raised ? darker : brighter);
      this.drawLine(x + 1, y + height, x + width, y + height);
      this.drawLine(x + width, y, x + width, y + height - 1);
      this.setColor(c);
   }

   public void fill3DRect(int x, int y, int width, int height, boolean raised) {
      Color c = this.getColor();
      Color brighter = c.brighter();
      Color darker = c.darker();
      if (!raised) {
         this.setColor(darker);
      }

      this.fillRect(x + 1, y + 1, width - 2, height - 2);
      this.setColor(raised ? brighter : darker);
      this.drawLine(x, y, x, y + height - 1);
      this.drawLine(x + 1, y, x + width - 2, y);
      this.setColor(raised ? darker : brighter);
      this.drawLine(x + 1, y + height - 1, x + width - 1, y + height - 1);
      this.drawLine(x + width - 1, y, x + width - 1, y + height - 2);
      this.setColor(c);
   }

   public abstract void drawOval(int var1, int var2, int var3, int var4);

   public abstract void fillOval(int var1, int var2, int var3, int var4);

   public abstract void drawArc(int var1, int var2, int var3, int var4, int var5, int var6);

   public abstract void fillArc(int var1, int var2, int var3, int var4, int var5, int var6);

   public abstract void drawPolygon(int[] var1, int[] var2, int var3);

   public void drawPolygon(Polygon p) {
      this.drawPolygon(p.xpoints, p.ypoints, p.npoints);
   }

   public abstract void fillPolygon(int[] var1, int[] var2, int var3);

   public void fillPolygon(Polygon p) {
      this.fillPolygon(p.xpoints, p.ypoints, p.npoints);
   }

   public abstract void drawString(String var1, int var2, int var3);

   public void drawChars(char[] data, int offset, int length, int x, int y) {
      this.drawString(new String(data, offset, length), x, y);
   }

   public void drawBytes(byte[] data, int offset, int length, int x, int y) {
      this.drawString(new String(data, 0, offset, length), x, y);
   }

   public abstract boolean drawImage(Image var1, int var2, int var3, ImageObserver var4);

   public abstract boolean drawImage(Image var1, int var2, int var3, int var4, int var5, ImageObserver var6);

   public abstract boolean drawImage(Image var1, int var2, int var3, Color var4, ImageObserver var5);

   public abstract boolean drawImage(Image var1, int var2, int var3, int var4, int var5, Color var6, ImageObserver var7);

   public abstract void dispose();

   public void finalize() {
      this.dispose();
   }

   public String toString() {
      return this.getClass().getName() + "[font=" + this.getFont() + ",color=" + this.getColor() + "]";
   }
}
