package java.awt;

import java.awt.image.ColorModel;
import java.awt.image.ImageObserver;
import java.awt.image.ImageProducer;
import java.awt.peer.ButtonPeer;
import java.awt.peer.CanvasPeer;
import java.awt.peer.CheckboxMenuItemPeer;
import java.awt.peer.CheckboxPeer;
import java.awt.peer.ChoicePeer;
import java.awt.peer.DialogPeer;
import java.awt.peer.FileDialogPeer;
import java.awt.peer.FramePeer;
import java.awt.peer.LabelPeer;
import java.awt.peer.ListPeer;
import java.awt.peer.MenuBarPeer;
import java.awt.peer.MenuItemPeer;
import java.awt.peer.MenuPeer;
import java.awt.peer.PanelPeer;
import java.awt.peer.ScrollbarPeer;
import java.awt.peer.TextAreaPeer;
import java.awt.peer.TextFieldPeer;
import java.awt.peer.WindowPeer;
import java.net.URL;

public abstract class Toolkit {
   private static Toolkit toolkit;

   protected abstract ButtonPeer createButton(Button var1);

   protected abstract TextFieldPeer createTextField(TextField var1);

   protected abstract LabelPeer createLabel(Label var1);

   protected abstract ListPeer createList(List var1);

   protected abstract CheckboxPeer createCheckbox(Checkbox var1);

   protected abstract ScrollbarPeer createScrollbar(Scrollbar var1);

   protected abstract TextAreaPeer createTextArea(TextArea var1);

   protected abstract ChoicePeer createChoice(Choice var1);

   protected abstract FramePeer createFrame(Frame var1);

   protected abstract CanvasPeer createCanvas(Canvas var1);

   protected abstract PanelPeer createPanel(Panel var1);

   protected abstract WindowPeer createWindow(Window var1);

   protected abstract DialogPeer createDialog(Dialog var1);

   protected abstract MenuBarPeer createMenuBar(MenuBar var1);

   protected abstract MenuPeer createMenu(Menu var1);

   protected abstract MenuItemPeer createMenuItem(MenuItem var1);

   protected abstract FileDialogPeer createFileDialog(FileDialog var1);

   protected abstract CheckboxMenuItemPeer createCheckboxMenuItem(CheckboxMenuItem var1);

   public abstract Dimension getScreenSize();

   public abstract int getScreenResolution();

   public abstract ColorModel getColorModel();

   public abstract String[] getFontList();

   public abstract FontMetrics getFontMetrics(Font var1);

   public abstract void sync();

   public static synchronized Toolkit getDefaultToolkit() {
      if (toolkit == null) {
         String nm = System.getProperty("awt.toolkit", "sun.awt.motif.MToolkit");

         try {
            toolkit = (Toolkit)Class.forName(nm).newInstance();
         } catch (ClassNotFoundException var1) {
            throw new AWTError("Toolkit not found: " + nm);
         } catch (InstantiationException var2) {
            throw new AWTError("Could not instantiate Toolkit: " + nm);
         } catch (IllegalAccessException var3) {
            throw new AWTError("Could not access Toolkit: " + nm);
         }
      }

      return toolkit;
   }

   public abstract Image getImage(String var1);

   public abstract Image getImage(URL var1);

   public abstract boolean prepareImage(Image var1, int var2, int var3, ImageObserver var4);

   public abstract int checkImage(Image var1, int var2, int var3, ImageObserver var4);

   public abstract Image createImage(ImageProducer var1);
}
