package java.awt;

import java.awt.peer.WindowPeer;

public class Window extends Container {
   String warningString;

   Window() {
      SecurityManager sm = System.getSecurityManager();
      if (sm != null && !sm.checkTopLevelWindow(this)) {
         this.warningString = System.getProperty("awt.appletWarning", "Warning: Applet Window");
      }

   }

   public Window(Frame parent) {
      SecurityManager sm = System.getSecurityManager();
      if (sm != null && !sm.checkTopLevelWindow(this)) {
         this.warningString = System.getProperty("awt.appletWarning", "Warning: Applet Window");
      }

      super.parent = parent;
      super.visible = false;
      ((Container)this).setLayout(new BorderLayout());
   }

   public synchronized void addNotify() {
      if (super.peer == null) {
         super.peer = this.getToolkit().createWindow(this);
      }

      super.addNotify();
   }

   public synchronized void pack() {
      if (super.peer == null) {
         this.addNotify();
      }

      ((Component)this).resize(((Container)this).preferredSize());
      ((Container)this).validate();
   }

   public synchronized void show() {
      if (super.peer == null) {
         this.addNotify();
      }

      ((Container)this).validate();
      if (super.visible) {
         this.toFront();
      } else {
         super.show();
      }
   }

   public synchronized void dispose() {
      ((Component)this).hide();
      ((Container)this).removeNotify();
   }

   public void toFront() {
      WindowPeer peer = (WindowPeer)super.peer;
      if (peer != null) {
         peer.toFront();
      }

   }

   public void toBack() {
      WindowPeer peer = (WindowPeer)super.peer;
      if (peer != null) {
         peer.toBack();
      }

   }

   public Toolkit getToolkit() {
      return Toolkit.getDefaultToolkit();
   }

   public final String getWarningString() {
      return this.warningString;
   }
}
