package java.awt.image;

import java.awt.Rectangle;
import java.util.Hashtable;

public class CropImageFilter extends ImageFilter {
   int cropX;
   int cropY;
   int cropW;
   int cropH;

   public CropImageFilter(int x, int y, int w, int h) {
      this.cropX = x;
      this.cropY = y;
      this.cropW = w;
      this.cropH = h;
   }

   public void setProperties(Hashtable props) {
      props.put("croprect", new Rectangle(this.cropX, this.cropY, this.cropW, this.cropH));
      super.setProperties(props);
   }

   public void setDimensions(int w, int h) {
      super.consumer.setDimensions(this.cropW, this.cropH);
   }

   public void setPixels(int x, int y, int w, int h, ColorModel model, byte[] pixels, int off, int scansize) {
      int x1 = x;
      if (x < this.cropX) {
         x1 = this.cropX;
      }

      int x2 = x + w;
      if (x2 > this.cropX + this.cropW) {
         x2 = this.cropX + this.cropW;
      }

      int y1 = y;
      if (y < this.cropY) {
         y1 = this.cropY;
      }

      int y2 = y + h;
      if (y2 > this.cropY + this.cropH) {
         y2 = this.cropY + this.cropH;
      }

      if (x1 < x2 && y1 < y2) {
         super.consumer.setPixels(x1 - this.cropX, y1 - this.cropY, x2 - x1, y2 - y1, model, pixels, off + (y1 - y) * scansize + (x1 - x), scansize);
      }
   }

   public void setPixels(int x, int y, int w, int h, ColorModel model, int[] pixels, int off, int scansize) {
      int x1 = x;
      if (x < this.cropX) {
         x1 = this.cropX;
      }

      int x2 = x + w;
      if (x2 > this.cropX + this.cropW) {
         x2 = this.cropX + this.cropW;
      }

      int y1 = y;
      if (y < this.cropY) {
         y1 = this.cropY;
      }

      int y2 = y + h;
      if (y2 > this.cropY + this.cropH) {
         y2 = this.cropY + this.cropH;
      }

      if (x1 < x2 && y1 < y2) {
         super.consumer.setPixels(x1 - this.cropX, y1 - this.cropY, x2 - x1, y2 - y1, model, pixels, off + (y1 - y) * scansize + (x1 - x), scansize);
      }
   }
}
