package java.awt.image;

public class DirectColorModel extends ColorModel {
   private int red_mask;
   private int green_mask;
   private int blue_mask;
   private int alpha_mask;
   private int red_offset;
   private int green_offset;
   private int blue_offset;
   private int alpha_offset;
   private int red_bits;
   private int green_bits;
   private int blue_bits;
   private int alpha_bits;
   private int accum_mask;

   public DirectColorModel(int bits, int rmask, int gmask, int bmask) {
      this(bits, rmask, gmask, bmask, 0);
   }

   public DirectColorModel(int bits, int rmask, int gmask, int bmask, int amask) {
      super(bits);
      this.red_mask = rmask;
      this.green_mask = gmask;
      this.blue_mask = bmask;
      this.alpha_mask = amask;
      this.CalculateOffsets();
   }

   public final int getRedMask() {
      return this.red_mask;
   }

   public final int getGreenMask() {
      return this.green_mask;
   }

   public final int getBlueMask() {
      return this.blue_mask;
   }

   public final int getAlphaMask() {
      return this.alpha_mask;
   }

   private void DecomposeMask(int mask, String componentName, int[] values) {
      if ((mask & this.accum_mask) != 0) {
         throw new IllegalArgumentException(componentName + " mask bits not unique");
      } else {
         int off = 0;
         int count = 0;
         if (mask != 0) {
            while((mask & 1) == 0) {
               mask >>>= 1;
               ++off;
            }

            while((mask & 1) == 1) {
               mask >>>= 1;
               ++count;
            }
         }

         if (mask != 0) {
            throw new IllegalArgumentException(componentName + " mask bits not contiguous");
         } else if (off + count > super.pixel_bits) {
            throw new IllegalArgumentException(componentName + " mask overflows pixel");
         } else {
            values[0] = off;
            values[1] = count;
         }
      }
   }

   private void CalculateOffsets() {
      int[] values = new int[2];
      this.DecomposeMask(this.red_mask, "red", values);
      this.red_offset = values[0];
      this.red_bits = values[1];
      this.DecomposeMask(this.green_mask, "green", values);
      this.green_offset = values[0];
      this.green_bits = values[1];
      this.DecomposeMask(this.blue_mask, "blue", values);
      this.blue_offset = values[0];
      this.blue_bits = values[1];
      this.DecomposeMask(this.alpha_mask, "alpha", values);
      this.alpha_offset = values[0];
      this.alpha_bits = values[1];
   }

   public final int getRed(int pixel) {
      if (this.red_mask == 0) {
         return 0;
      } else {
         int r = (pixel & this.red_mask) >>> this.red_offset;
         return this.red_bits == 8 ? r : r * 255 / ((1 << this.red_bits) - 1);
      }
   }

   public final int getGreen(int pixel) {
      if (this.green_mask == 0) {
         return 0;
      } else {
         int g = (pixel & this.green_mask) >>> this.green_offset;
         return this.green_bits == 8 ? g : g * 255 / ((1 << this.green_bits) - 1);
      }
   }

   public final int getBlue(int pixel) {
      if (this.blue_mask == 0) {
         return 0;
      } else {
         int b = (pixel & this.blue_mask) >>> this.blue_offset;
         return this.blue_bits == 8 ? b : b * 255 / ((1 << this.blue_bits) - 1);
      }
   }

   public final int getAlpha(int pixel) {
      if (this.alpha_mask == 0) {
         return 255;
      } else {
         int a = (pixel & this.alpha_mask) >>> this.alpha_offset;
         return this.alpha_bits == 8 ? a : a * 255 / ((1 << this.alpha_bits) - 1);
      }
   }

   public final int getRGB(int pixel) {
      return this.getAlpha(pixel) << 24 | this.getRed(pixel) << 16 | this.getGreen(pixel) << 8 | this.getBlue(pixel);
   }
}
