package java.awt.image;

import java.util.Hashtable;

public class FilteredImageSource implements ImageProducer {
   ImageProducer src;
   ImageFilter filter;
   private Hashtable proxies;

   public FilteredImageSource(ImageProducer orig, ImageFilter imgf) {
      this.src = orig;
      this.filter = imgf;
   }

   public synchronized void addConsumer(ImageConsumer ic) {
      if (this.proxies == null) {
         this.proxies = new Hashtable();
      }

      if (!this.proxies.contains(ic)) {
         ImageFilter imgf = this.filter.getFilterInstance(ic);
         this.proxies.put(ic, imgf);
         this.src.addConsumer(imgf);
      }

   }

   public synchronized boolean isConsumer(ImageConsumer ic) {
      return this.proxies != null && this.proxies.contains(ic);
   }

   public synchronized void removeConsumer(ImageConsumer ic) {
      if (this.proxies != null) {
         ImageFilter imgf = (ImageFilter)this.proxies.get(ic);
         if (imgf != null) {
            this.src.removeConsumer(imgf);
            this.proxies.remove(ic);
            if (this.proxies.isEmpty()) {
               this.proxies = null;
            }
         }
      }

   }

   public void startProduction(ImageConsumer ic) {
      if (this.proxies == null) {
         this.proxies = new Hashtable();
      }

      ImageFilter imgf = (ImageFilter)this.proxies.get(ic);
      if (imgf == null) {
         imgf = this.filter.getFilterInstance(ic);
         this.proxies.put(ic, imgf);
      }

      this.src.startProduction(imgf);
   }

   public void requestTopDownLeftRightResend(ImageConsumer ic) {
      if (this.proxies != null) {
         ImageFilter imgf = (ImageFilter)this.proxies.get(ic);
         if (imgf != null) {
            imgf.resendTopDownLeftRight(this.src);
         }
      }

   }
}
