package java.awt.image;

public class IndexColorModel extends ColorModel {
   private byte[] red;
   private byte[] green;
   private byte[] blue;
   private byte[] alpha;
   private int map_size;
   private int transparent_index;

   public IndexColorModel(int bits, int size, byte[] r, byte[] g, byte[] b) {
      this(bits, size, r, g, b, -1);
   }

   public IndexColorModel(int bits, int size, byte[] r, byte[] g, byte[] b, int trans) {
      super(bits);
      if (bits <= 8 && size <= 1 << bits) {
         this.map_size = size;
         this.red = new byte[256];
         System.arraycopy(r, 0, this.red, 0, size);
         this.green = new byte[256];
         System.arraycopy(g, 0, this.green, 0, size);
         this.blue = new byte[256];
         System.arraycopy(b, 0, this.blue, 0, size);
         this.setTransparentPixel(trans);
      } else {
         throw new ArrayIndexOutOfBoundsException();
      }
   }

   public IndexColorModel(int bits, int size, byte[] r, byte[] g, byte[] b, byte[] a) {
      this(bits, size, r, g, b, -1);
      this.alpha = new byte[256];
      System.arraycopy(a, 0, this.alpha, 0, size);
   }

   public IndexColorModel(int bits, int size, byte[] cmap, int start, boolean hasalpha) {
      this(bits, size, cmap, start, hasalpha, -1);
   }

   public IndexColorModel(int bits, int size, byte[] cmap, int start, boolean hasalpha, int trans) {
      super(bits);
      if (bits <= 8 && size <= 1 << bits) {
         this.map_size = size;
         this.red = new byte[256];
         this.green = new byte[256];
         this.blue = new byte[256];
         if (hasalpha) {
            this.alpha = new byte[256];
         }

         int j = start;

         for(int i = 0; i < size; ++i) {
            this.red[i] = cmap[j++];
            this.green[i] = cmap[j++];
            this.blue[i] = cmap[j++];
            if (hasalpha) {
               this.alpha[i] = cmap[j++];
            }
         }

         this.setTransparentPixel(trans);
      } else {
         throw new ArrayIndexOutOfBoundsException();
      }
   }

   public final int getMapSize() {
      return this.map_size;
   }

   public final int getTransparentPixel() {
      return this.transparent_index;
   }

   public final void getReds(byte[] r) {
      System.arraycopy(this.red, 0, r, 0, this.map_size);
   }

   public final void getGreens(byte[] g) {
      System.arraycopy(this.green, 0, g, 0, this.map_size);
   }

   public final void getBlues(byte[] b) {
      System.arraycopy(this.blue, 0, b, 0, this.map_size);
   }

   public final void getAlphas(byte[] a) {
      if (this.alpha != null) {
         System.arraycopy(this.alpha, 0, a, 0, this.map_size);
      } else {
         for(int i = 0; i < this.map_size; ++i) {
            a[i] = -1;
         }

         if (this.transparent_index >= 0) {
            a[this.transparent_index] = 0;
         }

      }
   }

   private void setTransparentPixel(int trans) {
      if (trans < this.map_size && trans >= 0) {
         if (this.alpha != null) {
            this.alpha[trans] = 0;
         }
      } else {
         trans = -1;
      }

      this.transparent_index = trans;
   }

   public final int getRed(int pixel) {
      return this.red[pixel];
   }

   public final int getGreen(int pixel) {
      return this.green[pixel];
   }

   public final int getBlue(int pixel) {
      return this.blue[pixel];
   }

   public final int getAlpha(int pixel) {
      if (pixel == this.transparent_index) {
         return 0;
      } else {
         return this.alpha != null ? this.alpha[pixel] : 255;
      }
   }

   public final int getRGB(int pixel) {
      return this.getAlpha(pixel) << 24 | (this.red[pixel] & 255) << 16 | (this.green[pixel] & 255) << 8 | this.blue[pixel] & 255;
   }
}
